@@ -244,6 +244,21 @@ class PluginAuthMessage(Message):
     context_ = StringProperty()
 
 
+class _OrderedMultiMapping :
+    def keys(self):
+        return self._keys
+    def values(self):
+        return self._values
+    def __len__(self):
+        return len(self._keys)
+    def __init__(self, list_of_keyval_tuples ):
+        self._keys = []
+        self._values = []
+        for k,v in list_of_keyval_tuples:
+            self._keys.append(k)
+            self._values.append(v)
+
+
 class IntegerIntegerMap(Message):
     _name = 'InxIvalPair_PI'
 
